/**
 * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
CKEDITOR.plugins.setLang( 'widget', 'de-ch', {
	'move': 'Zum Verschieben anwählen und ziehen',
	'label': '%1 Steuerelement'
} );
